@@ -33,7 +33,7 @@ is.proj <- function(crs) {
 .name_or_proj4 <- function(x) {
 	d <- .srs_describe(x@ptr$get_crs("wkt"))
 	r <- x@ptr$get_crs("proj4")
-	if (d$name != "unknown") {
+	if (!(d$name %in% c("unknown", "unnamed"))) {
 		if (substr(r, 1, 13) == "+proj=longlat") {
 			r <- paste("lon/lat", d$name)
 		} else {
@@ -42,9 +42,7 @@ is.proj <- function(crs) {
 		if (!is.na(d$EPSG)) {
 			r <- paste0(r, " (EPSG:", d$EPSG, ")")
 		} 
-	} else {
-		r <- x@ptr$get_crs("proj4")
-	}
+	} 
 	r
 }
 
@@ -92,6 +90,16 @@ setMethod("crs", signature("SpatRaster"),
 	}
 )
 
+setMethod("crs", signature("SpatRasterDataset"), 
+	function(x, proj=FALSE, describe=FALSE, parse=FALSE) {
+		if (length(x) > 0) {
+			.get_CRS(x[[1]], proj=proj, describe=describe, parse=parse)
+		} else {
+			NULL
+		}
+	}
+)
+
 
 .txtCRS <- function(x, warn=TRUE) {
 	if (inherits(x, "SpatVector") | inherits(x, "SpatRaster")) {
@@ -125,6 +133,8 @@ setMethod("crs<-", signature("SpatRaster", "ANY"),
 	}
 )
 
+
+
 #setMethod("crs<-", signature("SpatRaster", "character"), 
 #	function(x, ..., value) {
 #		x@ptr$set_crs(value[1])
