@@ -165,10 +165,17 @@ setMethod("inMemory", signature(x="SpatRaster"),
 
 
 setMethod("sources", signature(x="SpatRaster"), 
-	function(x) {
+	function(x, bands=FALSE) {
 		src <- x@ptr$filenames
 		src[src == ""] <= "memory"
-		data.frame(source=src, nlyr=x@ptr$nlyrBySource(), stringsAsFactors=FALSE)
+		if (bands) {
+			nls <- x@ptr$nlyrBySource()
+			data.frame(     sid=rep(1:length(src), nls), 
+						 source=rep(src, nls), 
+						 bands=x@ptr$getBands()+1, stringsAsFactors=FALSE)
+		} else {
+			data.frame(source=src, nlyr=x@ptr$nlyrBySource(), stringsAsFactors=FALSE)
+		}
 	}
 )
 
