@@ -1,18 +1,17 @@
 
 setMethod("zonal", signature(x="SpatRaster", z="SpatRaster"), 
 	function(x, z, fun="mean", ..., as.raster=FALSE, filename="", wopt=list())  {
-		txtfun <- .makeTextFun(match.fun(fun))
 		if (nlyr(z) > 1) {
 			z <- z[[1]]
 		}
-		if (inherits(txtfun, "character")) { 
-			if (txtfun %in% c("max", "min", "mean", "sum")) {
-				na.rm <- isTRUE(list(...)$na.rm)
-				opt <- spatOptions()
-				ptr <- x@ptr$zonal(z@ptr, txtfun, na.rm, opt)
-				messages(ptr, "zonal")
-				out <- .getSpatDF(ptr)
-			}
+		zname <- names(z)
+		txtfun <- .makeTextFun(match.fun(fun))
+		if (inherits(txtfun, "character") && (txtfun %in% c("max", "min", "mean", "sum"))) {
+			na.rm <- isTRUE(list(...)$na.rm)
+			opt <- spatOptions()
+			ptr <- x@ptr$zonal(z@ptr, txtfun, na.rm, opt)
+			messages(ptr, "zonal")
+			out <- .getSpatDF(ptr)
 		} else {
 			nl <- nlyr(x)
 			res <- list()
@@ -30,7 +29,6 @@ setMethod("zonal", signature(x="SpatRaster", z="SpatRaster"),
 				}
 			}
 		}
-
 		if (as.raster) {
 			if (is.null(wopt$names)) {
 				wopt$names <- names(x)
@@ -42,7 +40,7 @@ setMethod("zonal", signature(x="SpatRaster", z="SpatRaster"),
 				m <- match(out$zone, levs[,1])
 				out$zone <- levs[m, 2]
 			}
-			colnames(out)[1] <- names(z)
+			colnames(out)[1] <- zname
 			out
 		}
 	}
