@@ -26,7 +26,7 @@
 
 void shortDistPoints(std::vector<double> &d, const std::vector<double> &x, const std::vector<double> &y, const std::vector<double> &px, const std::vector<double> &py, const bool& lonlat, const double &lindist) {
 	if (lonlat) {
-		distanceCosineToNearest_lonlat(d, x, y, px, py);
+		distanceToNearest_lonlat(d, x, y, px, py);
 	} else {
 		distanceToNearest_plane(d, x, y, px, py, lindist);
 	}
@@ -73,13 +73,13 @@ SpatRaster SpatRaster::distance_vector_rasterize(SpatVector p, bool align_points
 	}
 	
 	bool lonlat = is_lonlat(); // m == 0
-	double torad = 0.0174532925199433;
-	if (lonlat) {
-		for (size_t i=0; i<pxy[0].size(); i++) {
-			pxy[0][i] *= torad;
-			pxy[1][i] *= torad;
-		}
-	}
+	//double torad = 0.0174532925199433;
+	//if (lonlat) {
+	//	for (size_t i=0; i<pxy[0].size(); i++) {
+	//		pxy[0][i] *= torad;
+	//		pxy[1][i] *= torad;
+	//	}
+	//}
 	
 	unsigned nc = ncol();
 	if (!readStart()) {
@@ -108,12 +108,12 @@ SpatRaster SpatRaster::distance_vector_rasterize(SpatVector p, bool align_points
 		} 
 		std::vector<std::vector<double>> xy = xyFromCell(cells);
 		std::vector<double> d(cells.size(), 0); 
-		if (lonlat) {
-			for (size_t i=0; i<xy[0].size(); i++) {
-				xy[0][i] *= torad;
-				xy[1][i] *= torad;
-			}
-		}
+		//if (lonlat) {
+		//	for (size_t i=0; i<xy[0].size(); i++) {
+		//		xy[0][i] *= torad;
+		//		xy[1][i] *= torad;
+		//	}
+		//}
 		shortDistPoints(d, xy[0], xy[1], pxy[0], pxy[1], lonlat, m);
 		if (!out.writeValues(d, out.bs.row[i], out.bs.nrows[i], 0, nc)) return out;
 	}
@@ -1445,7 +1445,10 @@ double area_polygon_lonlat(geod_geodesic &g, const std::vector<double> &lon, con
 	geod_polygon_init(&p, 0);
 	size_t n = lat.size();
 	for (size_t i=0; i < n; i++) {
-		geod_polygon_addpoint(&g, &p, lat[i], lon[i]);
+		//double lat = lat[i] > 90 ? 90 : lat[i] < -90 ? -90 : lat[i];
+		// for #397
+		double flat = lat[i] < -90 ? -90 : lat[i];
+		geod_polygon_addpoint(&g, &p, flat, lon[i]);
 	}
 	double area, P;
 	geod_polygon_compute(&g, &p, 0, 1, &area, &P);
@@ -1724,7 +1727,8 @@ SpatRaster SpatRaster::rst_area(bool mask, std::string unit, bool transform, Spa
 		}
 		if (disagg) {
 			out.writeStop();
-			SpatRaster tmp = out.to_memory_copy();
+			SpatOptions dopt(opt);
+			SpatRaster tmp = out.to_memory_copy(dopt);
 			std::vector<unsigned> fact = {1,2};
 			opt.overwrite=true;
 			out = tmp.aggregate(fact, "sum", true, opt); 
@@ -1799,7 +1803,7 @@ std::vector<double> SpatRaster::sum_area(std::string unit, bool transform, SpatO
 	if (is_lonlat()) {
 		SpatRaster x = geometry(1);
 		SpatExtent extent = x.getExtent();
-		SpatOptions opt;
+		//SpatOptions opt;
 		if ((x.ncol() == 1) && ((extent.xmax - extent.xmin) > 180)) {
 			std::vector<unsigned> fact= {1,2};
 			x = x.disaggregate(fact, opt);
